@@ -56,7 +56,11 @@ _USERAGENT_SDK_NAME = 'Botocore'
 _USERAGENT_FEATURE_MAPPINGS = {
     'WAITER': 'B',
     'PAGINATOR': 'C',
+    'RETRY_MODE_STANDARD': 'E',
+    'RETRY_MODE_ADAPTIVE': 'F',
     'S3_TRANSFER': 'G',
+    'PROTOCOL_RPC_V2_CBOR': 'M',
+    'GZIP_REQUEST_COMPRESSION': 'L',
     'ENDPOINT_OVERRIDE': 'N',
     'SIGV4A_SIGNING': 'S',
 }
